"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizePackageJson = void 0;
/**
 * Strip off non-pruning related fields from package.json
 * Remove devDependencies if production target
 * Remove optional peerDependencies if production target
 *
 * @param packageJson
 * @param isProduction
 * @param projectName
 * @returns
 */
function normalizePackageJson(packageJson, isProduction) {
    const normalized = Object.assign({ name: packageJson.name, version: packageJson.version || '0.0.0' }, (packageJson.license && { license: packageJson.license }));
    if (packageJson.dependencies) {
        normalized.dependencies = packageJson.dependencies;
    }
    if (packageJson.devDependencies && !isProduction) {
        normalized.devDependencies = packageJson.devDependencies;
    }
    if (packageJson.peerDependencies) {
        if (isProduction) {
            const normalizedPeedDeps = filterOptionalPeerDependencies(packageJson);
            if (normalizedPeedDeps) {
                normalized.peerDependencies = normalizedPeedDeps;
            }
        }
        else {
            normalized.peerDependencies = packageJson.peerDependencies;
            if (packageJson.peerDependenciesMeta) {
                normalized.peerDependenciesMeta = packageJson.peerDependenciesMeta;
            }
        }
    }
    return normalized;
}
exports.normalizePackageJson = normalizePackageJson;
function filterOptionalPeerDependencies(packageJson) {
    let peerDependencies;
    Object.keys(packageJson.peerDependencies).forEach((key) => {
        var _a, _b;
        if (!((_b = (_a = packageJson.peerDependenciesMeta) === null || _a === void 0 ? void 0 : _a[key]) === null || _b === void 0 ? void 0 : _b.optional)) {
            peerDependencies = peerDependencies || {};
            peerDependencies[key] = packageJson.peerDependencies[key];
        }
    });
    return peerDependencies;
}
//# sourceMappingURL=pruning.js.map